==> maxdb-all-linux-32bit-i386-7_5_00_38.tgz: SAPDB/Install/Cleaner.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V75/c_00/develop/sys/src/install/perl/SAPDB/Install/Cleaner.pm#3 $
# $DateTime: 2003/12/11 13:40:27 $
# $Change: 59245 $
#
# Desc: 
#    ========== licence begin  GPL
#    Copyright (c) 2005 SAP AG
#
#    This program is free software; you can redistribute it and/or
#    modify it under the terms of the GNU General Public License
#    as published by the Free Software Foundation; either version 2
#    of the License, or (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#    ========== licence end


package SAPDB::Install::Cleaner;

# here you can set references of global vars containing objects which should cleaned up
# it works with scalars, arrays and hashes only

$VERSION = 1.01;

sub BEGIN {
      my $repo = SAPDB::Install::Repository::GetCurrent ();
	my @neededPackages=(
		'Base',
		'Trace'
	);
	foreach my $package (@neededPackages) {
	  	unless (defined $repo->Eval ("SAPDB::Install::$package", 1.01)) {
                print join ("\n", $repo->GetErr)."\n";
                die;
        	}
		SAPDB::Install::Exporter::import ("SAPDB::Install::$package");
	  } 
}

@ISA=qw(SAPDB::Install::Base);

$DEBUG = 0;


# members of class 
my %members=(
	VARREFS => \@tmp
);

sub new{
	my ($type,$path,$log) = @_;
	my $self= SAPDB::Install::Base->new;
	foreach my $key (keys(%members)){
		$self->{$key}=$members{$key};
	}
	$self = bless $self,$type;
	return $self;
}


sub SetRef{
	my ($self,$ref)=@_;
	local *reflist=$self->VARREFS;
	push @reflist,$ref;
	1;
}


sub DESTROY{
	my $self=shift;
	foreach my $ref (@{$self->VARREFS}){
		*deref=$ref;
		if(ref($ref) eq 'SCALAR'){
			TraceMsg("unset scalar\n",4,\$DEBUG);
			$deref=undef;
			next;
		}
		elsif(ref($ref) eq 'HASH'){
			 foreach my $key (keys(%deref)){
				TraceMsg("unset hash key $key\n",4,\$DEBUG);
				$deref{$key}=undef;	
			 }
			  next; 
		}
		elsif(ref($ref) eq 'ARRAY'){
			my $count=$#deref+1;
			for (my $i = 0;$i<$count;$i++){
				TraceMsg("unset array index $i\n",4,\$DEBUG);
				$deref[$i]=undef;
			}	
			next; 
		}
		elsif(ref($ref)=~/SAPDB::Install/){
			TraceMsg("unset object instance\n",4,\$DEBUG);
			$defef=undef;
		}
		elsif(ref($ref) eq 'REF'){
             TraceMsg("unset reference to a ".ref($deref)."\n",4,\$DEBUG);
			 $deref=undef;
		}
		else{
			print2stderr("Cleaner: this member is no scalar, hash, array or object reference\n");
		} 
	}
	$self->SAPDB::Install::Base::DESTROY;
}

1;

==> maxdb-all-linux-32bit-i386-7_6_02_10.tgz: SAPDB/Install/Cleaner.pm <==
#!/usr/bin/perl
#
# $Header: //sapdb/V76/c_02/b_10/sys/src/install/perl/SAPDB/Install/Cleaner.pm#1 $
# $DateTime: 2007/03/28 16:58:41 $
# $Change: 148814 $
#
# Desc: 

package SAPDB::Install::Cleaner;

# here you can set references of global vars containing objects which should cleaned up
# it works with scalars, arrays and hashes only

use SAPDB::Install::Base;
use SAPDB::Install::Trace;

our @ISA=qw(SAPDB::Install::Base);

our $DEBUG = 0;

# members of class 
my %members=(
	VARREFS => \@tmp
);

sub new{
	my ($type,$path,$log) = @_;
	my $self= SAPDB::Install::Base->new;
	foreach my $key (keys(%members)){
		$self->{$key}=$members{$key};
	}
	$self = bless $self,$type;
	return $self;
}


sub SetRef{
	my ($self,$ref)=@_;
	local *reflist=$self->VARREFS;
	push @reflist,$ref;
	1;
}


sub DESTROY{
	my $self=shift;
	foreach my $ref (@{$self->VARREFS}){
		*deref=$ref;
		if(ref($ref) eq 'SCALAR'){
			TraceMsg("unset scalar: $deref\n",4,\$DEBUG);
			$deref=undef;
			next;
		}
		elsif(ref($ref) eq 'HASH'){
			 foreach my $key (keys(%deref)){
				TraceMsg("unset hash key $key:".$deref{$key}."\n",4,\$DEBUG);
				$deref{$key}=undef;	
			 }
			  next; 
		}
		elsif(ref($ref) eq 'ARRAY'){
			my $count=$#deref+1;
			for (my $i = 0;$i<$count;$i++){
				TraceMsg("unset array index $i: ".$deref[$i]."\n",4,\$DEBUG);
				$deref[$i]=undef;
			}	
			next; 
		}
		elsif(ref($ref)=~/SAPDB::Install/){
			TraceMsg("unset object instance: $deref\n",4,\$DEBUG);
			$defef=undef;
		}
		elsif(ref($ref) eq 'REF'){
             TraceMsg("unset reference to a ".ref($deref)."\n",4,\$DEBUG);
			 $deref=undef;
		}
		else{
			print2stderr("Cleaner: this member is no scalar, hash, array or object reference\n");
		} 
	}
	$self->SAPDB::Install::Base::DESTROY;
}

1;
